@@ -20,6 +20,8 @@
 
 # Standard imports
 import sys
+from pkg_resources import parse_version
+
 from PySide2.QtCore import (
     QCoreApplication,
     QSettings,
@@ -65,9 +67,6 @@ def main():
     # Translations
     load_translations(app)
 
-    # Load default external links
-    load_default_external_links()
-
     # debug settings
     # from cutevariant.gui.settings import *
     # w = SettingsWidget()
@@ -80,6 +79,15 @@ def main():
     splash.show()
     app.processEvents()
 
+    #  Drop settings if old version
+    settings = QSettings()
+    settings_version = settings.value("version", None)
+    if settings_version is None or parse_version(settings_version) < parse_version(
+        __version__
+    ):
+        settings.clear()
+        settings.setValue("version", __version__)
+
     # Display
     w = MainWindow()
 
@@ -143,18 +151,6 @@ def load_translations(app):
         app_settings.setValue("ui/locale", "en")
 
 
-def load_default_external_links():
-    """Load default external DB links if the list is empty"""
-    app_settings = QSettings()
-    app_settings.beginGroup("plugins/variant_view/links")
-
-    # If no value: add default values
-    if not app_settings.childKeys():
-        for db_name, db_url in cm.WEBSITES_URLS.items():
-            app_settings.setValue(db_name, db_url)
-    app_settings.endGroup()
-
-
 def process_arguments(app):
     """Arguments parser"""
     parser = QCommandLineParser()
