@@ -3,6 +3,7 @@ import functools
 import math
 import csv
 import io
+import time
 import itertools as it
 from collections import defaultdict
 import copy
@@ -171,7 +172,11 @@ class VariantModel(QAbstractTableModel):
 
             # ---- Display Role ----
             if role == Qt.DisplayRole:
-                return str(self.variant(index.row())[column_name])
+                value = self.variant(index.row())[column_name]
+                if value is None:
+                    return "NULL"
+                else:
+                    return str(self.variant(index.row())[column_name])
 
     def headerData(self, section, orientation=Qt.Horizontal, role=Qt.DisplayRole):
         """Overrided: Return column name and display tooltips on headers
@@ -318,6 +323,8 @@ class VariantModel(QAbstractTableModel):
         self.count_runnable.query_number = self.query_number
         # Start the run
         LOGGER.debug("Start pools; query number %s", self.query_number)
+        self._start_timer = time.perf_counter()
+
         self.pool.start(self.variant_runnable)
         self.pool.start(self.count_runnable)
 
@@ -352,6 +359,8 @@ class VariantModel(QAbstractTableModel):
 
         # LOGGER.debug(cmd.count_cmd.cache_info())
         LOGGER.debug("Received load data; query %s", query_number)
+        self._end_timer = time.perf_counter()
+        self.elapsed_time = self._end_timer - self._start_timer
 
         self.beginResetModel()
         self.variants.clear()
@@ -567,8 +576,13 @@ class VariantView(QWidget):
             )
         # Display nb of variants/groups and pages
         self.info_label = QLabel()
-        self.bottom_bar.addWidget(self.info_label)
+        self.time_label = QLabel()
+
+        self.bottom_bar.addAction(FIcon(0xF0A30), "sql", self.on_show_sql)
+        self.bottom_bar.addWidget(self.time_label)
+        self.bottom_bar.addSeparator()
         self.bottom_bar.addWidget(spacer)
+        self.bottom_bar.addWidget(self.info_label)
         self.bottom_bar.setIconSize(QSize(16, 16))
         self.bottom_bar.setMaximumHeight(30)
         self.bottom_bar.setContentsMargins(0, 0, 0, 0)
@@ -604,6 +618,8 @@ class VariantView(QWidget):
         self.model.load_finished.connect(self.loaded)
         # Connect errors from async runnables
         self.model.runnable_exception.connect(self.runnable_exception)
+        #  connect double clicke
+        self.view.doubleClicked.connect(self.on_double_clicked)
 
     def _set_loading(self, active=True):
         """Slot to obtain the status of async load: started/finished
@@ -633,6 +649,7 @@ class VariantView(QWidget):
 
     def load(self):
         self.model.page = 1
+        self.model.order_by = None
         self.model.load()
 
     def loaded(self):
@@ -732,12 +749,20 @@ class VariantView(QWidget):
     def on_show_sql(self):
         """Display debug sql query"""
         msg_box = QMessageBox()
+        msg_box.setWindowTitle("SQL debug")
         msg_box.setText(self.model.debug_sql)
+        explain_query = []
+        for rec in self.conn.execute("EXPLAIN QUERY PLAN " + self.model.debug_sql):
+            explain_query.append(str(dict(rec)))
+
+        msg_box.setDetailedText("\n".join(explain_query))
+
         msg_box.exec_()
 
     def load_page_box(self):
         """Load Bottom toolbar with pagination"""
         self.page_box.clear()
+        self.time_label.setText(str(" Executed in %.2gs " % (self.model.elapsed_time)))
         if self.model.pageCount() - 1 == 0:
             self.set_pagging_enabled(False)
         else:
@@ -807,25 +832,27 @@ class VariantView(QWidget):
 
         # Create external links
         links_menu = menu.addMenu(self.tr("External links"))
-        self.settings.beginGroup("plugins/variant_view/links")
+        size = self.settings.beginReadArray("plugins/variant_view/links")
         # Display only external links with placeholders that can be mapped
-        for key in self.settings.childKeys():
-            format_string = self.settings.value(key)
-            # Get placeholders
-            field_names = {
-                name
-                for text, name, spec, conv in string.Formatter().parse(format_string)
-            }
-            if field_names & full_variant.keys():
-                # Full or partial mapping => accepted link
-                links_menu.addAction(
-                    key,
-                    functools.partial(
-                        QDesktopServices.openUrl,
-                        QUrl(format_string.format(**full_variant), QUrl.TolerantMode),
-                    ),
+        for index in range(size):
+            self.settings.setArrayIndex(index)
+            key = self.settings.value("name")
+            is_default = bool(int(self.settings.value("is_default", 0)))
+            format_string = self.settings.value("url")
+
+            url = self._create_url(format_string, full_variant)
+
+            if url:
+                action = links_menu.addAction(
+                    f"{key}", functools.partial(QDesktopServices.openUrl, url)
                 )
-        self.settings.endGroup()
+
+                #  set bold if default
+                # font = QFont()
+                # font.setBold(is_default)
+                # action.setFont(font)
+
+        self.settings.endArray()
 
         # Comment action
         on_edit = functools.partial(self.edit_comment, current_index)
@@ -846,6 +873,28 @@ class VariantView(QWidget):
         # Display
         menu.exec_(event.globalPos())
 
+    def _create_url(self, format_string: str, variant: dict) -> QUrl:
+        """Create a link from a format string and a variant data 
+        
+        Args:
+            format_string (str): a string with format group like : http://www.google.fr?q={chr}
+            variant (dict): a variant dict returned by sql.get_one_variant.
+        
+        Returns:
+            QUrl: return url or return None
+        
+        """
+        field_names = {
+            name
+            for _, name, _, _ in string.Formatter().parse(format_string)
+            if name is not None
+        }
+        if field_names & variant.keys():
+            # Full or partial mapping => accepted link
+            return QUrl(format_string.format(**variant), QUrl.TolerantMode)
+        else:
+            return None
+
     def update_favorites(self, checked: bool):
         """Update favorite status of multiple selected variants
 
@@ -936,6 +985,35 @@ class VariantView(QWidget):
         QApplication.instance().clipboard().setText(output.getvalue())
         output.close()
 
+    def on_double_clicked(self, index: QModelIndex):
+        """ 
+        React on double clicked
+        TODO : duplicate code with ContextMenu Event ! Need to refactor a bit 
+        """
+        current_variant = self.model.variant(index.row())
+        full_variant = sql.get_one_variant(self.conn, current_variant["id"])
+        # Update variant with currently displayed fields (not in variants table)
+        full_variant.update(current_variant)
+
+        # Look from settings the default open link
+        format_string = None
+        size = self.settings.beginReadArray("plugins/variant_view/links")
+        for index in range(size):
+            self.settings.setArrayIndex(index)
+            print(self.settings.value("name"), self.settings.value("is_default"))
+            is_default = bool(int(self.settings.value("is_default")))
+            if is_default:
+                format_string = self.settings.value("url")
+                break
+        self.settings.endArray()
+
+        #  Create and open link
+        if format_string:
+            # Get placeholders
+            url = self._create_url(format_string, full_variant)
+            if url:
+                QDesktopServices.openUrl(url)
+
 
 class VariantViewWidget(plugin.PluginWidget):
     """Contains the view of query with several controller"""
